==> openshift-model-config-6.6.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterConditionFluentImpl<A extends ClusterConditionFluent<A>> extends BaseFluent<A> implements ClusterConditionFluent<A>{
  public ClusterConditionFluentImpl() {
  }
  public ClusterConditionFluentImpl(ClusterCondition instance) {
    this.withPromql(instance.getPromql()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private PromQLClusterConditionBuilder promql;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildPromql instead.
   * @return The buildable object.
   */
  @Deprecated
  public PromQLClusterCondition getPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  public PromQLClusterCondition buildPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  public A withPromql(PromQLClusterCondition promql) {
    _visitables.get("promql").remove(this.promql);
    if (promql!=null){ this.promql= new PromQLClusterConditionBuilder(promql); _visitables.get("promql").add(this.promql);} else { this.promql = null; _visitables.get("promql").remove(this.promql); } return (A) this;
  }
  public Boolean hasPromql() {
    return this.promql != null;
  }
  public A withNewPromql(String promql) {
    return (A)withPromql(new PromQLClusterCondition(promql));
  }
  public ClusterConditionFluent.PromqlNested<A> withNewPromql() {
    return new ClusterConditionFluentImpl.PromqlNestedImpl();
  }
  public ClusterConditionFluent.PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item) {
    return new ClusterConditionFluentImpl.PromqlNestedImpl(item);
  }
  public ClusterConditionFluent.PromqlNested<A> editPromql() {
    return withNewPromqlLike(getPromql());
  }
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromql() {
    return withNewPromqlLike(getPromql() != null ? getPromql(): new PromQLClusterConditionBuilder().build());
  }
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item) {
    return withNewPromqlLike(getPromql() != null ? getPromql(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterConditionFluentImpl that = (ClusterConditionFluentImpl) o;
    if (promql != null ? !promql.equals(that.promql) :that.promql != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(promql,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (promql != null) { sb.append("promql:"); sb.append(promql + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PromqlNestedImpl<N> extends PromQLClusterConditionFluentImpl<ClusterConditionFluent.PromqlNested<N>> implements ClusterConditionFluent.PromqlNested<N>,Nested<N>{
    PromqlNestedImpl(PromQLClusterCondition item) {
      this.builder = new PromQLClusterConditionBuilder(this, item);
    }
    PromqlNestedImpl() {
      this.builder = new PromQLClusterConditionBuilder(this);
    }
    PromQLClusterConditionBuilder builder;
    public N and() {
      return (N) ClusterConditionFluentImpl.this.withPromql(builder.build());
    }
    public N endPromql() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterConditionFluentImpl<A extends ClusterConditionFluent<A>> extends BaseFluent<A> implements ClusterConditionFluent<A>{
  public ClusterConditionFluentImpl() {
  }
  public ClusterConditionFluentImpl(ClusterCondition instance) {
    if (instance != null) {
      this.withPromql(instance.getPromql());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private PromQLClusterConditionBuilder promql;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildPromql instead.
   * @return The buildable object.
   */
  @Deprecated
  public PromQLClusterCondition getPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  public PromQLClusterCondition buildPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  public A withPromql(PromQLClusterCondition promql) {
    _visitables.get("promql").remove(this.promql);
    if (promql!=null){ this.promql= new PromQLClusterConditionBuilder(promql); _visitables.get("promql").add(this.promql);} else { this.promql = null; _visitables.get("promql").remove(this.promql); } return (A) this;
  }
  public Boolean hasPromql() {
    return this.promql != null;
  }
  public A withNewPromql(String promql) {
    return (A)withPromql(new PromQLClusterCondition(promql));
  }
  public ClusterConditionFluentImpl.PromqlNested<A> withNewPromql() {
    return new ClusterConditionFluentImpl.PromqlNestedImpl();
  }
  public ClusterConditionFluentImpl.PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item) {
    return new ClusterConditionFluentImpl.PromqlNestedImpl(item);
  }
  public ClusterConditionFluentImpl.PromqlNested<A> editPromql() {
    return withNewPromqlLike(getPromql());
  }
  public ClusterConditionFluentImpl.PromqlNested<A> editOrNewPromql() {
    return withNewPromqlLike(getPromql() != null ? getPromql(): new PromQLClusterConditionBuilder().build());
  }
  public ClusterConditionFluentImpl.PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item) {
    return withNewPromqlLike(getPromql() != null ? getPromql(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterConditionFluentImpl that = (ClusterConditionFluentImpl) o;
    if (!java.util.Objects.equals(promql, that.promql)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(promql,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (promql != null) { sb.append("promql:"); sb.append(promql + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PromqlNestedImpl<N> extends PromQLClusterConditionFluentImpl<ClusterConditionFluentImpl.PromqlNested<N>> implements ClusterConditionFluentImpl.PromqlNested<N>,Nested<N>{
    PromqlNestedImpl(PromQLClusterCondition item) {
      this.builder = new PromQLClusterConditionBuilder(this, item);
    }
    PromqlNestedImpl() {
      this.builder = new PromQLClusterConditionBuilder(this);
    }
    PromQLClusterConditionBuilder builder;
    public N and() {
      return (N) ClusterConditionFluentImpl.this.withPromql(builder.build());
    }
    public N endPromql() {
      return and();
    }
    
  }
  
}
